## resilient

This package is a Python client module for the Resilient REST API.

### Installation  
Instructions for building and installing this package can be found in the 
[repository README](https://github.com/ibmresilient/resilient-python-api/blob/master/README.md).


### Tests  
python setup.py test [-a "<optional co3argparse args>"] [-c <config file>] [-p "<optional pytest args>"]  
e.g. `python setup.py test -a "--org=Test" -c ~/my.config -p "-s"`
   
